<template>
  <el-bus-crud ref="crud" v-bind="tableConfig" />
</template>

<script>
import { getSortConfig } from '@/utils/form-item-config'
export default {
  data() {
    return {
      tableConfig: {
        url: 'flower/api/flower/zone/page/flower/list',
        hasNew: false,
        hasEdit: false,
        hasDelete: false,
        hasView: false,
        extraQuery: {
          zoneId: this.$route.params.id,
        },
        columns: [
          { label: '商品名称', prop: 'name', minWidth: 150, fixed: 'left' },
          {
            label: '商品封面',
            formatter: (row) =>
              row.cover ? (
                <el-bus-image
                  src={row.cover}
                  lazy={true}
                  style="width:50px;height:50px"
                ></el-bus-image>
              ) : null,
            minWidth: 100,
          },
          { label: '级别', prop: 'levelStr', minWidth: 80 },
          { label: '颜色', prop: 'color', minWidth: 100 },
          { label: '供应商名称', prop: 'supplierName', minWidth: 150 },
          { label: '商品售价', prop: 'price', minWidth: 120 },
          { label: '库存', prop: 'stock', minWidth: 120 },
          { label: '商品状态', prop: 'statusStr', minWidth: 80 },
          { label: '商品标签', prop: 'tags', minWidth: 150 },
          { label: '提交时间', prop: 'createTime', minWidth: 180 },
          { label: '排序', prop: 'zoneRank', minWidth: 120, fixed: 'right' },
        ],
        searchForm: [
          {
            type: 'row',
            items: [
              { label: '商品名称：', id: 'name', type: 'input' },
              { label: '供应商：', id: 'supplierName', type: 'input' },
            ],
          },
        ],
        extraButtons: [
          {
            text: '设置排序',
            atClick: (row) => {
              this.$refs.crud.$refs.extraDialog[0].show({
                flowerId: row.id,
                rank: row.zoneRank,
              })
              return false
            },
          },
        ],
        extraDialogs: [
          {
            title: '设置排序',
            form: [
              {
                id: 'flowerId',
                type: 'input',
                hidden: () => true,
              },
              {
                ...getSortConfig('rank'),
              },
            ],
            atConfirm: async (val) => {
              const { code } = await this.$elBusHttp.request(
                'flower/api/flower/zone/page/set/rank',
                {
                  method: 'post',
                  data: {
                    ...val,
                    id: this.$route.params.id,
                  },
                }
              )
              if (code === 0) {
                this.$message.success('设置成功')
              }
            },
          },
        ],
      },
    }
  },
  head() {
    return {
      title: '专区商品',
    }
  },
}
</script>
